Interchange

Struct Interchange 

pub struct Interchange { /* private fields */ }

Implementations

Source

impl Interchange

pub fn from_arrow_54(df: Vec<RecordBatch>) -> Result<Self, InterchangeError>

Move Arrow version 54 to the Arrow data interchange format.

Source

impl Interchange

pub fn from_arrow_55(df: Vec<RecordBatch>) -> Result<Self, InterchangeError>

Move Arrow version 55 to the Arrow data interchange format.

Source

impl Interchange

pub fn from_arrow_56(df: Vec<RecordBatch>) -> Result<Self, InterchangeError>

Move Arrow version 56 to the Arrow data interchange format.

Source

impl Interchange

pub fn from_arrow_57(df: Vec<RecordBatch>) -> Result<Self, InterchangeError>

Move Arrow version 57 to the Arrow data interchange format.

Source

impl Interchange

pub fn from_arrow_58(df: Vec<RecordBatch>) -> Result<Self, InterchangeError>

Move Arrow version 58 to the Arrow data interchange format.

Source

impl Interchange

pub fn from_polars_0_53(df: DataFrame) -> Result<Self, InterchangeError>

Move Polars version 0_53 to the Arrow data interchange format.

Source

impl Interchange

pub fn from_polars_0_44(df: DataFrame) -> Result<Self, InterchangeError>

Move Polars version 0_44 to the Arrow data interchange format.

Source

impl Interchange

pub fn from_polars_0_45(df: DataFrame) -> Result<Self, InterchangeError>

Move Polars version 0_45 to the Arrow data interchange format.

Source

impl Interchange

pub fn from_polars_0_46(df: DataFrame) -> Result<Self, InterchangeError>

Move Polars version 0_46 to the Arrow data interchange format.

Source

impl Interchange

pub fn from_polars_0_47(df: DataFrame) -> Result<Self, InterchangeError>

Move Polars version 0_47 to the Arrow data interchange format.

Source

impl Interchange

pub fn from_polars_0_48(df: DataFrame) -> Result<Self, InterchangeError>

Move Polars version 0_48 to the Arrow data interchange format.

Source

impl Interchange

pub fn from_polars_0_49(df: DataFrame) -> Result<Self, InterchangeError>

Move Polars version 0_49 to the Arrow data interchange format.

Source

impl Interchange

pub fn from_polars_0_50(df: DataFrame) -> Result<Self, InterchangeError>

Move Polars version 0_50 to the Arrow data interchange format.

Source

impl Interchange

pub fn from_polars_0_51(df: DataFrame) -> Result<Self, InterchangeError>

Move Polars version 0_51 to the Arrow data interchange format.

Source

impl Interchange

pub fn from_polars_0_52(df: DataFrame) -> Result<Self, InterchangeError>

Move Polars version 0_52 to the Arrow data interchange format.

Source

impl Interchange

pub fn from_polars_0_42(df: DataFrame) -> Result<Self, InterchangeError>

Move Polars version 0_42 to the Arrow data interchange format.

Source

impl Interchange

pub fn from_polars_0_43(df: DataFrame) -> Result<Self, InterchangeError>

Move Polars version 0_43 to the Arrow data interchange format.

Source

impl Interchange

pub fn from_polars_0_40(df: DataFrame) -> Result<Self, InterchangeError>

Move Polars version 0_40 to the Arrow data interchange format.

Source

impl Interchange

pub fn from_polars_0_41(df: DataFrame) -> Result<Self, InterchangeError>

Move Polars version 0_41 to the Arrow data interchange format.

Source

impl Interchange

pub fn to_arrow_54(self) -> Result<Vec<RecordBatch>, InterchangeError>

Move Arrow data interchange format to Arrow version 54.

Source

impl Interchange

pub fn to_arrow_55(self) -> Result<Vec<RecordBatch>, InterchangeError>

Move Arrow data interchange format to Arrow version 55.

Source

impl Interchange

pub fn to_arrow_56(self) -> Result<Vec<RecordBatch>, InterchangeError>

Move Arrow data interchange format to Arrow version 56.

Source

impl Interchange

pub fn to_arrow_57(self) -> Result<Vec<RecordBatch>, InterchangeError>

Move Arrow data interchange format to Arrow version 57.

Source

impl Interchange

pub fn to_arrow_58(self) -> Result<Vec<RecordBatch>, InterchangeError>

Move Arrow data interchange format to Arrow version 58.

Source

impl Interchange

pub fn to_polars_0_53(self) -> Result<DataFrame, InterchangeError>

Move Arrow data interchange format to Polars version 0_53.

Source

impl Interchange

pub fn to_polars_0_43(self) -> Result<DataFrame, InterchangeError>

Move Arrow data interchange format to Polars version 0_43.

Source

impl Interchange

pub fn to_polars_0_44(self) -> Result<DataFrame, InterchangeError>

Move Arrow data interchange format to Polars version 0_44.

Source

impl Interchange

pub fn to_polars_0_45(self) -> Result<DataFrame, InterchangeError>

Move Arrow data interchange format to Polars version 0_45.

Source

impl Interchange

pub fn to_polars_0_46(self) -> Result<DataFrame, InterchangeError>

Move Arrow data interchange format to Polars version 0_46.

Source

impl Interchange

pub fn to_polars_0_47(self) -> Result<DataFrame, InterchangeError>

Move Arrow data interchange format to Polars version 0_47.

Source

impl Interchange

pub fn to_polars_0_48(self) -> Result<DataFrame, InterchangeError>

Move Arrow data interchange format to Polars version 0_48.

Source

impl Interchange

pub fn to_polars_0_49(self) -> Result<DataFrame, InterchangeError>

Move Arrow data interchange format to Polars version 0_49.

Source

impl Interchange

pub fn to_polars_0_50(self) -> Result<DataFrame, InterchangeError>

Move Arrow data interchange format to Polars version 0_50.

Source

impl Interchange

pub fn to_polars_0_51(self) -> Result<DataFrame, InterchangeError>

Move Arrow data interchange format to Polars version 0_51.

Source

impl Interchange

pub fn to_polars_0_52(self) -> Result<DataFrame, InterchangeError>

Move Arrow data interchange format to Polars version 0_52.

Source

impl Interchange

pub fn to_polars_0_41(self) -> Result<DataFrame, InterchangeError>

Move Arrow data interchange format to Polars version 0_41.

Source

impl Interchange

pub fn to_polars_0_42(self) -> Result<DataFrame, InterchangeError>

Move Arrow data interchange format to Polars version 0_42.

Source

impl Interchange

pub fn to_polars_0_40(self) -> Result<DataFrame, InterchangeError>

Move Arrow data interchange format to Polars version 0_40.