pub struct Interchange { /* private fields */ }Implementations
Sourceimpl Interchange
impl Interchange
Sourcepub fn from_arrow_54(df: Vec<RecordBatch>) -> Result<Self, InterchangeError>
pub fn from_arrow_54(df: Vec<RecordBatch>) -> Result<Self, InterchangeError>
Move Arrow version 54 to the Arrow data interchange format.
Sourceimpl Interchange
impl Interchange
Sourcepub fn from_arrow_55(df: Vec<RecordBatch>) -> Result<Self, InterchangeError>
pub fn from_arrow_55(df: Vec<RecordBatch>) -> Result<Self, InterchangeError>
Move Arrow version 55 to the Arrow data interchange format.
Sourceimpl Interchange
impl Interchange
Sourcepub fn from_polars_0_44(df: DataFrame) -> Result<Self, InterchangeError>
pub fn from_polars_0_44(df: DataFrame) -> Result<Self, InterchangeError>
Move Polars version 0_44 to the Arrow data interchange format.
Sourceimpl Interchange
impl Interchange
Sourcepub fn from_polars_0_45(df: DataFrame) -> Result<Self, InterchangeError>
pub fn from_polars_0_45(df: DataFrame) -> Result<Self, InterchangeError>
Move Polars version 0_45 to the Arrow data interchange format.
Sourceimpl Interchange
impl Interchange
Sourcepub fn from_polars_0_46(df: DataFrame) -> Result<Self, InterchangeError>
pub fn from_polars_0_46(df: DataFrame) -> Result<Self, InterchangeError>
Move Polars version 0_46 to the Arrow data interchange format.
Sourceimpl Interchange
impl Interchange
Sourcepub fn from_polars_0_47(df: DataFrame) -> Result<Self, InterchangeError>
pub fn from_polars_0_47(df: DataFrame) -> Result<Self, InterchangeError>
Move Polars version 0_47 to the Arrow data interchange format.
Sourceimpl Interchange
impl Interchange
Sourcepub fn from_polars_0_48(df: DataFrame) -> Result<Self, InterchangeError>
pub fn from_polars_0_48(df: DataFrame) -> Result<Self, InterchangeError>
Move Polars version 0_48 to the Arrow data interchange format.
Sourceimpl Interchange
impl Interchange
Sourcepub fn from_polars_0_49(df: DataFrame) -> Result<Self, InterchangeError>
pub fn from_polars_0_49(df: DataFrame) -> Result<Self, InterchangeError>
Move Polars version 0_49 to the Arrow data interchange format.
Sourceimpl Interchange
impl Interchange
Sourcepub fn from_polars_0_42(df: DataFrame) -> Result<Self, InterchangeError>
pub fn from_polars_0_42(df: DataFrame) -> Result<Self, InterchangeError>
Move Polars version 0_42 to the Arrow data interchange format.
Sourceimpl Interchange
impl Interchange
Sourcepub fn from_polars_0_43(df: DataFrame) -> Result<Self, InterchangeError>
pub fn from_polars_0_43(df: DataFrame) -> Result<Self, InterchangeError>
Move Polars version 0_43 to the Arrow data interchange format.
Sourceimpl Interchange
impl Interchange
Sourcepub fn from_polars_0_40(df: DataFrame) -> Result<Self, InterchangeError>
pub fn from_polars_0_40(df: DataFrame) -> Result<Self, InterchangeError>
Move Polars version 0_40 to the Arrow data interchange format.
Sourceimpl Interchange
impl Interchange
Sourcepub fn from_polars_0_41(df: DataFrame) -> Result<Self, InterchangeError>
pub fn from_polars_0_41(df: DataFrame) -> Result<Self, InterchangeError>
Move Polars version 0_41 to the Arrow data interchange format.
Sourceimpl Interchange
impl Interchange
Sourcepub fn to_arrow_54(self) -> Result<Vec<RecordBatch>, InterchangeError>
pub fn to_arrow_54(self) -> Result<Vec<RecordBatch>, InterchangeError>
Move Arrow data interchange format to Arrow version 54.
Sourceimpl Interchange
impl Interchange
Sourcepub fn to_arrow_55(self) -> Result<Vec<RecordBatch>, InterchangeError>
pub fn to_arrow_55(self) -> Result<Vec<RecordBatch>, InterchangeError>
Move Arrow data interchange format to Arrow version 55.
Sourceimpl Interchange
impl Interchange
Sourcepub fn to_polars_0_43(self) -> Result<DataFrame, InterchangeError>
pub fn to_polars_0_43(self) -> Result<DataFrame, InterchangeError>
Move Arrow data interchange format to Polars version 0_43.
Sourceimpl Interchange
impl Interchange
Sourcepub fn to_polars_0_44(self) -> Result<DataFrame, InterchangeError>
pub fn to_polars_0_44(self) -> Result<DataFrame, InterchangeError>
Move Arrow data interchange format to Polars version 0_44.
Sourceimpl Interchange
impl Interchange
Sourcepub fn to_polars_0_45(self) -> Result<DataFrame, InterchangeError>
pub fn to_polars_0_45(self) -> Result<DataFrame, InterchangeError>
Move Arrow data interchange format to Polars version 0_45.
Sourceimpl Interchange
impl Interchange
Sourcepub fn to_polars_0_46(self) -> Result<DataFrame, InterchangeError>
pub fn to_polars_0_46(self) -> Result<DataFrame, InterchangeError>
Move Arrow data interchange format to Polars version 0_46.
Sourceimpl Interchange
impl Interchange
Sourcepub fn to_polars_0_47(self) -> Result<DataFrame, InterchangeError>
pub fn to_polars_0_47(self) -> Result<DataFrame, InterchangeError>
Move Arrow data interchange format to Polars version 0_47.
Sourceimpl Interchange
impl Interchange
Sourcepub fn to_polars_0_48(self) -> Result<DataFrame, InterchangeError>
pub fn to_polars_0_48(self) -> Result<DataFrame, InterchangeError>
Move Arrow data interchange format to Polars version 0_48.
Sourceimpl Interchange
impl Interchange
Sourcepub fn to_polars_0_49(self) -> Result<DataFrame, InterchangeError>
pub fn to_polars_0_49(self) -> Result<DataFrame, InterchangeError>
Move Arrow data interchange format to Polars version 0_49.
Sourceimpl Interchange
impl Interchange
Sourcepub fn to_polars_0_41(self) -> Result<DataFrame, InterchangeError>
pub fn to_polars_0_41(self) -> Result<DataFrame, InterchangeError>
Move Arrow data interchange format to Polars version 0_41.
Sourceimpl Interchange
impl Interchange
Sourcepub fn to_polars_0_42(self) -> Result<DataFrame, InterchangeError>
pub fn to_polars_0_42(self) -> Result<DataFrame, InterchangeError>
Move Arrow data interchange format to Polars version 0_42.
Sourceimpl Interchange
impl Interchange
Sourcepub fn to_polars_0_40(self) -> Result<DataFrame, InterchangeError>
pub fn to_polars_0_40(self) -> Result<DataFrame, InterchangeError>
Move Arrow data interchange format to Polars version 0_40.